Index: background.js |
=================================================================== |
--- a/background.js |
+++ b/background.js |
@@ -110,7 +110,7 @@ |
var activeNotification = null; |
// Adds or removes page action icon according to options. |
function refreshIconAndContextMenu(tab) |
{ |
if(!/^https?:/.test(tab.url)) |
@@ -128,15 +128,15 @@ |
iconFilename = excluded ? "icons/abp-19-whitelisted.png" : "icons/abp-19.png"; |
} |
- tab.pageAction.setIcon(iconFilename); |
- tab.pageAction.setTitle(ext.i18n.getMessage("name")); |
+ tab.browserAction.setIcon(iconFilename); |
+ tab.browserAction.setTitle(ext.i18n.getMessage("name")); |
iconAnimation.registerTab(tab, iconFilename); |
if (localStorage.shouldShowIcon == "false") |
- tab.pageAction.hide(); |
+ tab.browserAction.hide(); |
else |
- tab.pageAction.show(); |
+ tab.browserAction.show(); |
if (require("info").platform == "chromium") // TODO: Implement context menus for Safari |
// Set context menu status according to whether current tab has whitelisted domain |
@@ -110,7 +110,7 @@ |
var activeNotification = null; |
-// Adds or removes page action icon according to options. |
+// Adds or removes browser action icon according to options. |
function refreshIconAndContextMenu(tab) |
{ |